@@ -160,21 +160,23 @@ class Profile (Structure):
         Other methods
     ===============================================================
     """
-    def add_account(self, acc, protected=True):
+    def add_account(self, acc):
         """
         Add account to this profile.
         
         @param acc (Account) account we want to add 
         @return None
         """
-        if protected:
-            same_acc = Account.find(type(acc), acc.username, self)
-            if same_acc:
-                raise WarningExc('Profile add_account',
-                                 'Same account already exists')
+
         acc.prof = self
 
 
+    def remove_account(self, acc):
+        if acc in self.accounts:
+            acc.prof = None
+
+
+    '''
     def del_profile(self):
         """
         Delete this profile with all accounts from DB
@@ -183,10 +185,10 @@ class Profile (Structure):
         """
         acc_list = self.accounts
         for i in acc_list:
-            i.del_account()
+            i.prof = None
 
         self._del_struct()
-
+    '''
 
     def copy(self):
         """
