@@ -25,7 +25,7 @@ from ldm.Account import Account
 from ldm.SqlDriver import TIME_FORMAT
 from ProxyedTransp import ProxyedTransp
 from Service import Service
-from ScriboExc import XmlrpcExc, SocketExc
+from ScriboExc import XmlrpcExc, SocketExc, WarningExc
 
 MAX_EVENTS = 50
 MAX_SKIP = 100
@@ -331,6 +331,16 @@ class LivejAccount(Account, Service):
         return None
 
 
+    def refresh_post(self, msg):
+
+        result = self._get_post(msg.custom_id)
+        if result:
+            self._parse_post(result, msg)
+        else:
+            raise WarningExc("LivejAccount","Post was deleted! Try update list of post")
+
+
+
     def refresh_posts(self, callback):
         """
         Download post and search for updates in journal and sync. with local 
@@ -793,16 +803,14 @@ class LivejAccount(Account, Service):
         """
 
         param = {
-                 'username': self.username,
-                 'hpassword': self.hpassword,
-                 'ver': '1',
                  'lineendings': 'unix',
                  'selecttype': 'one',
                  'itemid': postid,
                  'howmany': '1'
                 }
         result = self.exec_xmlrpc('getevents', param)
-
+        if result['events'] == []:
+            return  None
         return result['events'][0]
 
 
