@@ -9,8 +9,6 @@
 
 from time import *
 import sys
-sys.path.append("..")
-sys.path.append("../ldm")
 from ScriboExc import WarningExc
 
 import Misc
