@@ -10,8 +10,6 @@
 
 from PyQt4 import QtCore
 from PyQt4 import QtGui
-
-#from HomePage import home_page
 from ToolbarWindow import ToolbarWindow
 from MainWindow import *
 from ldm.Profile import *
@@ -67,17 +65,32 @@ class AddPostWindow(MainWindow):
         self.combo_view.addItem(self.tr("Preview"))
         self.connect(self.combo_view,QtCore.SIGNAL("currentIndexChanged(int)"),
                          self.reload_edit)
+        #if post will be edited
         if msg:
-            self.text_edit.insertPlainText(msg.text)
+            author = msg.poster
             self.start_text = msg.text
+            #update post
+            try:
+                author.refresh_post(msg)
+            except WarningExc, exc:
+                super(AddPostWindow, self).show_warning(exc)
+                return
+
+            self.text_edit.insertPlainText(msg.text)
+            if self.start_text != msg.text:
+                ret = QtGui.QMessageBox.information(self, self.tr("Scribo"),
+                                                self.tr("Post was edited"),
+                                                QtGui.QMessageBox.Yes)
+                self.start_text = msg.text
             title = msg.title
             if not msg.title:
                 title = ""
             self.title_edit.setText(title)
+    
         self.title_edit.setFocus()
-
         self.connect(self.text_edit, QtCore.SIGNAL("undoAvailable(bool)"),self.undo_available)
         self.connect(self.text_edit, QtCore.SIGNAL("redoAvailable(bool)"),self.redo_available)
+
         self.create_actions()
         first_toolbar = self.create_toolbar()
         second_toolbar = self.create_toolbar_second()
@@ -178,12 +191,8 @@ class AddPostWindow(MainWindow):
         self.redo_act.setSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
         self.connect(self.redo_act, QtCore.SIGNAL("clicked()"),
                      self.text_edit.redo)
-        
-
-
+    
         self.send_act = QtGui.QToolButton(self)
-
-
         if not self.msg:
             self.send_act.setIcon(QtGui.QIcon(self.tr("../data/en/post_send_to.png")))
             self.send_act.setText(self.tr("Send to.."))
@@ -203,9 +212,10 @@ class AddPostWindow(MainWindow):
         handler for button OK
         @return
         """
+        #if we send post from preview, send current edited post
+        #(try except send adding html title)
         if self.combo_view.currentIndex() == 1:
             text_post =self.plain_text
-            #QtCore.QString(unicode(self.text_edit.toHtml())).trimmed()
         else:
             text_post = QtCore.QString(unicode(self.text_edit.toPlainText())).trimmed()
 
@@ -240,9 +250,10 @@ class AddPostWindow(MainWindow):
         handler for button OK
         @return
         """
+        #if we send post from preview, send current edited post
+        #(try except send adding html title)
         if self.combo_view.currentIndex() == 1:
             text_post = self.plain_text
-            #QtCore.QString(unicode(self.text_edit.toHtml())).trimmed()
         else:
             text_post = QtCore.QString(unicode(self.text_edit.toPlainText())).trimmed()
 
@@ -272,13 +283,18 @@ class AddPostWindow(MainWindow):
         try:
             res = author.edit_post(mes)
         except WarningExc, exc:
-            super(AddPost, self).show_warning(exc)
+            super(AddPostWindow, self).show_warning(exc)
         else:
             ret = QtGui.QMessageBox.information(self, self.tr("Scribo"),
                                                 self.tr("Post is edit"),
                                                 QtGui.QMessageBox.Yes)
         mes.del_msg_tree()
-        super(AddPost, self).home_window()
+        self.sending_post = True
+        try:
+            author.refresh_post(self.msg)
+        except WarningExc, exc:
+            super(AddPostWindow, self).show_warning(exc)
+        super(AddPostWindow, self).home_window()
 
 
     def pict_post(self):
@@ -346,9 +362,6 @@ class AddPostWindow(MainWindow):
         '''
         marked text insert between tags
         '''
-        #start = self.text_edit.selectionStart()
-        #if start <> -1:
-            #text = self.text_edit.selectedText()
         self.dial = QtGui.QMessageBox()
         
         but_box = QtGui.QDialogButtonBox()
@@ -392,6 +405,9 @@ class AddPostWindow(MainWindow):
             return
 
     def html_click(self, button):
+        """
+        dialog adding html in the text
+        """
         text = self.text_edit.textCursor().selectedText()
 
         if button == self.bold_button:
@@ -476,12 +492,20 @@ class AddPostWindow(MainWindow):
         return res
 
     def undo_available(self, undo):
+        """
+        handler changes avalaible undo status
+        @param undo = True or False
+        """
         if undo:
             self.undo_act.setDisabled(False)
         else:
             self.undo_act.setDisabled(True)
 
     def redo_available(self, redo):
+        """
+        handler changes avalaible redo status
+        @param redo = True or False
+        """
         if redo:
             self.redo_act.setDisabled(False)
         else:
