@@ -10,8 +10,6 @@
 
 from PyQt4 import QtCore
 from PyQt4 import QtGui
-
-#from HomePage import home_page
 from ldm.Profile import main_prof
 from ToolbarWindow import ToolbarWindow
 from MainWindow import *
@@ -54,7 +52,6 @@ class ListMyPosts(MainWindow):
         """
         list_widget = QtGui.QListWidget(self.centr_widg)
         self.list = self.get_messages()
-        #upic = QtGui.QImage("../data/faviconLJ.ico")
         index = 0
 
         if len(self.list) == 0:
@@ -185,41 +182,38 @@ class ListMyPosts(MainWindow):
                                self.tr("Please, choose messages to delete!"),
                                QtGui.QMessageBox.Yes)
 
-
-
-
     def reload_window(self):
         """
         refresh list of posts 
         @param          
         @return
         """
-        self.progress = QtGui.QProgressDialog(self.tr("Operation is in progress."),
-                                              self.tr("Cancel"), 0, 100, self)
-        self.progress.setWindowTitle(self.tr("Receiving data..."))
-        self.progress.setWindowModality(QtCore.Qt.WindowModal)
-        self.value_progress = 1
-        self.progress.setValue(self.value_progress)
-
-        self.progress.forceShow()
-
+        self.progress = MyProgress(self)
         self.refresh_messages()
-            #acc.get_posts(self.callback)
-        self.progress.setValue(self.progress.maximum())
+        self.progress.close()
+
+    def end_refresh(self):
+        """
+        update list messages from database
+        """
         self.hbox.removeWidget(self.mes_list)
         self.mes_list.deleteLater()
         self.mes_list = self.list_posts()
         self.hbox.addWidget(self.mes_list)
 
     def callback(self):
-        #20 = BASE
-        self.progress.setValue(100 * (self.value_progress / (self.value_progress + 20)))
-        self.value_progress = self.value_progress + 1
-        print "!!!"
-
+        """
+        update toolbar
+        """
+        self.progress.setValue(100 * (self.progress.value_progress / (self.progress.value_progress + 4.5)))
+        self.progress.value_progress = self.progress.value_progress + 1.1
+        QtCore.QCoreApplication.processEvents()
+        
 
     def refresh_messages(self):
-
+        """
+        update list of messages from network
+        """
         list_acc = main_prof.accounts
         for acc in list_acc:
             try:
@@ -229,8 +223,36 @@ class ListMyPosts(MainWindow):
 
 
     def get_messages(self):
+        """
+        getting all messages
+        """
         return main_prof.get_posts()
 
+class MyProgress(QtGui.QProgressDialog):
+    """
+    class with common ProgressBar
+    """
+    def __init__(self, parent):
+        """
+        initialization ProgressBar
+        """
+        QtGui.QProgressDialog.__init__(self, parent)
+        self.setLabelText(self.tr("Operation is in progress."))
+        self.setCancelButtonText(self.tr("Cancel"))
+        self.parent = parent
+        self.setWindowTitle(self.tr("Receiving data..."))
+        self.setWindowModality(QtCore.Qt.WindowModal)
+        self.value_progress = 1.1
+        self.setValue(self.value_progress)
+        self.forceShow()
+        
+    def closeEvent(self, event):
+        """
+        closing progressbar
+        """
+        self.setValue(self.maximum())
+        event.accept()
+        self.parent.end_refresh()
 
 from ViewMessage import *
 
