@@ -17,10 +17,6 @@ __license__ = "GPLv2"
 import sys
 from PyQt4 import QtCore
 from PyQt4 import QtGui
-
-#sys.path.append("../ldm")
-#sys.path.append("..")
-
 from ldm.Profile import main_prof
 
 class MainWindow(QtGui.QMainWindow):
@@ -50,7 +46,7 @@ class MainWindow(QtGui.QMainWindow):
         self.manage_act = QtGui.QAction(self.tr("&Edit Accounts"), self)
         self.create_actions_menu()
         self.create_menus()
-        #self.show()
+        
 
     def new_profile(self):
         """
@@ -81,7 +77,8 @@ class MainWindow(QtGui.QMainWindow):
         from About import __version__ as ver
         QtGui.QMessageBox.about(self, self.tr("About Scribo"),
                                 self.tr("A mobile multiblog client."\
-                                        " \n Version: " + ver))
+                                        " \n Version: " + ver+
+                                        "\n More information you can get from README file."))
     def show_warning(self, exc):
         """  
         error message
@@ -146,7 +143,9 @@ class MainWindow(QtGui.QMainWindow):
         if self.parent:
             self.parent.show()
         else:
-            ret = QtGui.QMessageBox.question(self, self.tr("Scribo"), self.tr("Do you really want to quit?"), QtGui.QMessageBox.Yes, QtGui.QMessageBox.No)
+            ret = QtGui.QMessageBox.question(self, self.tr("Scribo"),
+                                             self.tr("Do you really want to quit?"),
+                                             QtGui.QMessageBox.Yes, QtGui.QMessageBox.No)
             if (ret == QtGui.QMessageBox.No):
                 return
     
@@ -160,30 +159,31 @@ class MainWindow(QtGui.QMainWindow):
         child = self
         del_window = []
         while parent<>None:
-            print parent
-            print child
             del_window.append(child)
             child = parent
             parent = parent.parent
             
         for window in del_window:
             window.close()
-        #child.show()
-
-
-    def reload_window(self):
+	child.show()
+	return child
+	
+    def reload_home_window(self):
         """
-        handler for clicked "reload"
+        reload home window (if profile is changed)
         @param
         @return
         """
-        pass
-
-    def home_start(self):
-        from HomePage import home_window
-        self.parent = self
-        self.close()
-
+        self = self.home_window()
+        if not main_prof.accounts:
+           from StartPage import StartPage
+           self.parent = StartPage()
+        else:
+            from HomePage import HomePage
+	    home_page = HomePage()
+            self.parent = home_page 
+        self = self.home_window()
+        
 main_window = MainWindow()
 
 
