@@ -59,8 +59,12 @@ class ViewMessage(MainWindow):
         QWebSettings.globalSettings().setAttribute(QWebSettings.JavascriptEnabled,
                                                    False)
         #cache settings
-        QWebSettings.globalSettings().setAttribute(QWebSettings.LocalStorageEnabled,
-                                                   True)
+        try:
+            QWebSettings.globalSettings().setAttribute(QWebSettings.LocalStorageEnabled,
+                                                       True)
+        except AttributeError:
+            pass
+            
         #connect plugins for video
         QWebSettings.globalSettings().setAttribute(QWebSettings.PluginsEnabled,
                                                    True)
@@ -95,7 +99,6 @@ class ViewMessage(MainWindow):
         @return web_mes_widg - webkit widget with title, date, text message
         and its parent message 
         """
-        #web = QWebView(self)
         title = msg.title
         text = msg.text
         user = msg.poster
@@ -343,7 +346,6 @@ class ViewMessage(MainWindow):
         @param
         @return                                          
         """
-        print "edit_post"
         edit_widg = AddPostWindow(parent=self, msg=self.msg)
     
 
@@ -364,12 +366,9 @@ class ViewMessage(MainWindow):
         @param
         @return                                                                  
         """
-        #self.vbox.removeWidget(self.view_mes_widget)
-        #self.view_mes_widget = 
         self.msg.read = True
         self.view_mes(self.msg)
         self.view_mes_widget.show()
-        #self.vbox.addWidget(self.view_mes_widget)
 
     def refresh_mes(self):
         """
@@ -381,7 +380,6 @@ class ViewMessage(MainWindow):
         try:
             acc.refresh_posts(self.callback)
         except WarningExc, exc:
-            #setSelected(select)
             super(ViewMessage, self).show_warning(exc)
         else:
             self.reload_window()
